/*!
 * \file mux_tb.v
 * \author Benjamin Zhai (benjamin.zhai@sensima.com)
 * \version 0.1
 * \date 20131114
 * \brief 2-1 Bus Multiplexer Core Testbench
 *
 * Copyright © 2013 Sensima Technology SA \n
 * Company Confidential \n
 *
 * Project: MA-FTDI bridge \n
 * Module: Interface and buffer between MA sensor and FTDI \n
 *
 * Rivision History: \n
 * 0.1     - rev 70     - 20130930 - Initial version \n
 * \todo  
 *        - 
 */
 
`timescale 1ns / 100ps
// synthesis loop_limit 4000

module mux_tb();

reg en;
reg  [7:0] i0;
reg  [7:0] i1;
reg sel;
wire [7:0] dout;

defparam DUT.WIDTH=8;
defparam DUT.DEFAULT=8'h5a;
mux DUT ( 	.en_i(en),
			.i0_i(i0),
			.i1_i(i1),
			.sel_i(sel),
			.dout_o(dout)
		);

initial
begin
	$display($time, ": ==== Starting simulation ====");
	en = 1'b0;
	i0 = 8'h0;
	i1 = 8'hff;
	sel = 1'b0;
	#20 en = 1'b1;
	#20 en = 1'b0;
	#20 en = 1'b1;
	#20 i0 = 8'haa;
	#20 sel = 1'b1;
	#20 i1 = 8'h55;
	#20 $stop;
end

// signal monitoring block
initial
begin
    $monitor($time, ": Monitor: en_i=%b, i0=%b, i1=%b, sel=%b, dout=%b",en,i0,i1,sel,dout);
end

endmodule
